@@ -1,5 +1,5 @@
 """Top-level package for Astrophysics toolset."""
 
 __author__ = """Corentin Cadiou"""
-__email__ = 'c.cadiou@ucl.ac.uk'
-__version__ = '0.1.0'
+__email__ = "c.cadiou@ucl.ac.uk"
+__version__ = "__version__ = '0.2.1'"
