@@ -2,4 +2,4 @@
 
 from collections import namedtuple
 
-IOResult = namedtuple('IOResult', ['data', 'metadata'])
\ No newline at end of file
+IOResult = namedtuple("IOResult", ["data", "metadata"])
